@@ -36,6 +36,20 @@ class Rate(BaseModel):
         return  v
 
 
+class Vol(BaseModel):
+    date: str
+    rate: float
+
+    @validator('rate')
+    def valid_rate(cls, v):
+        
+        try:
+            x = float(v)
+        except:
+            raise ValueError('rate must be a number')
+        return  v
+
+
 class Holiday(BaseModel):
     date: str
 
@@ -289,6 +303,20 @@ class CallabilityPrice(BaseModel):
     option_type: OptionType = OptionType.calloption
 
 
+class ConvertibleFixedRate(FixedRateBond):
+    redemption: float 
+    conversion_price: float
+    conversion_ratio: float 
+    dividend_yield: float = 0.0
+    dividend_structure: List[CashFlow] = []
+    credit_spread: float = 0.0
+    stock_price: float
+    call_list: List[CallabilityPrice] =[]
+    put_list: List[CallabilityPrice] = []
+    exercise_type: OptionExercise = OptionExercise.american
+    european_expiry: Optional[str] = None
+
+
 class FlatForwardCurve(BaseModel):
     date: str
     rate: float
@@ -349,3 +377,20 @@ class SRMG2(BaseModel):
     sigma: float = 0.01
     eta: float = 0.01
     rho: float = -0.75
+
+
+class VolCurve(BaseModel):
+    strike: float
+    vols: List[Vol] = []
+
+
+class VolSurface(BaseModel):
+    surface: List[VolCurve] = []
+
+
+class HestonProcessParam(BaseModel):
+    v0: float =  0.01
+    kappa: float = 0.01
+    theta: float = 0.01
+    sigma: float = 0.01
+    rho: float = 0.0
\ No newline at end of file
