@@ -77,11 +77,16 @@ def qlSchedule_from_Structure(structures: List[Structure]):
     dates.append(structures[0].start_date)
     for structure in structures:
         dates.append(structure.end_date)
-
+    #print(dates)
     qlschedule = ql.Schedule([datestr_to_qldate(dt) for dt in dates])
     return qlschedule
 
 
+def qlDividendSchedule_from_CashFLows(cashflows: List[CashFlow]):
+    schedule = ql.DividendSchedule([ ql.SimpleCashFlow(cf.amount, datestr_to_qldate(cf.date)) for cf in cashflows])
+    return schedule
+
+
 def get_qlPeriod(tenor:str):
     prd = tenor[-1]
     number = int(tenor[:len(tenor)-1])
@@ -131,6 +136,23 @@ def qlSchedule(issue_date: str,
     return schedule
 
 
+def qlSchedule2(thebond: FixedRateBond,
+            ql_calendar):
+    
+    vdate = datestr_to_qldate(thebond.issue_date)
+    mdate = datestr_to_qldate(thebond.maturity)
+    
+    schedule = ql.Schedule(vdate, 
+                mdate, 
+                ql.Period(ql_frequency[thebond.settings.frequency]), 
+                ql_calendar, 
+                ql_business_day[thebond.settings.business_day],
+                ql_business_day[thebond.settings.terminate_business_day], 
+                ql_date_generation[thebond.settings.date_gen], 
+                thebond.settings.is_eom)
+    return schedule
+
+
 def qlMakeScedule(issue_date: str, maturity: str, frequency:str, ql_calendar = None,
                 business_day: Optional[BusinessDay] = None, 
                 maturity_business_day: Optional[BusinessDay] = None,
