@@ -5,6 +5,7 @@ from .pymodels import *
 from .ql_utils import *
 from .ql_conventions import *
 from .termstructure import *
+from fpql import pymodels
 
 
 def flat_forward():
@@ -126,6 +127,29 @@ def sample_bondinfo():
     return thebond, setting
 
 
+def sample_convertiblebondinfo():
+    bondsetting = {
+        "frequency":Frequency.semi_annual,
+        "start_basis": StartBasis.today,
+        "day_count": DayCount.act_act_isma,
+        "business_day": BusinessDay.no_adjustment,
+        "terminate_business_day": BusinessDay.no_adjustment,
+        "date_gen": DateGeneration.backward,
+        "is_eom":  True
+        }
+
+    setting = BondSetting(**bondsetting)
+
+    bonddata = {"issue_date": "2021-08-18", 
+                "maturity": "2031-08-18", 
+                "settings": setting, 
+                "coupon": 5.75,
+                "face_value": 100
+                }
+    thebond = FixedRateBond(**bonddata)
+
+    return thebond
+
 # NOTE: it is possible but yet to be tested to have multiple coupons
 # for a fixed rate bond since the argument accepts list of coupons
 def sample_fixedratebond():
@@ -405,6 +429,53 @@ def callable_bondinfo():
     thebond = FixedRateBond(**bonddata)
 
     return thebond, setting
+    
+
+def convertibles_fixedratebond():
+    thebond = sample_convertiblebondinfo()
+    bond_dict = thebond.dict()
+    bond_dict["redemption"] = 100.00
+    bond_dict["conversion_price"] = 26.00
+    bond_dict["conversion_ratio"] = 3.84615
+    bond_dict["dividend_yield"] =   2
+    bond_dict["stock_price"] = 29.04
+    bond_dict["credit_spread"] = 3.0
+    bond_dict["exercise_type"] = OptionExercise.european
+    bond_dict["european_expiry"] = "2028-08-18"
+
+    calendar =ql.WeekendsOnly()
+    conv_bond = pymodels.ConvertibleFixedRate(**bond_dict)
+    #Create schedule to create sample callability and puttable
+    schedule = qlSchedule2(conv_bond, calendar)
+    dates = list(schedule)
+    no_of_dates = len(dates)
+    call_start = int(no_of_dates/4)
+    put_start = int(no_of_dates/2)
+
+    calls = []
+    for i in range(call_start, put_start ):
+        calldict = {"price_type": BondPriceType.clean,
+                    "price": 100.00,
+                    "date": dates[i].ISO(),
+                    "option_type":OptionType.calloption}
+        callprices = CallabilityPrice(**calldict)
+        calls.append(callprices)  
+    conv_bond.call_list = calls
+    
+    puts = []
+    for i in range(put_start + 1, no_of_dates):
+        putdict = {"price_type": BondPriceType.clean,
+                    "price": 100.00,
+                    "date": dates[i].ISO(),
+                    "option_type": OptionType.putoption}
+        putprices = CallabilityPrice(**putdict)
+        puts.append(putprices)
+    conv_bond.put_list = puts
+
+    conv_bond.structure = structure_from_qlSchedule(conv_bond, schedule )
+    
+
+    return conv_bond
 
 
 def curve_with_spread(value_date: str):
